==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Provjera je gotovo završena, hvala vam na strpljenju</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Pripremanje</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Provjereno za neke greške</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Dobrodošli, sustav je uspješno ažuriran</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Trenutno izdanje:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Uspješno ažurirano</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Vaše će se računalo isključiti uskoro %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Neuspjelo ažuriranje</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nepoznata greška</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Nedovoljno prostora na disku. Molim očistite disk i pokušajte ponovno.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dependency error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG greška</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Priprema za dopune...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-update/translations/dde-update_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Provjera je gotovo završena, hvala vam na strpljenju</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Pripremanje</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Provjereno za neke greške</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Dobrodošli, sustav je uspješno ažuriran</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Trenutno izdanje:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Uspješno ažurirano</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Vaše će se računalo isključiti uskoro %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Neuspjelo ažuriranje</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nepoznata greška</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Nedovoljno prostora na disku. Molim očistite disk i pokušajte ponovno.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG greška</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Odustani</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Priprema za dopune...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
